#[repr(u8)]pub enum Error {
InvalidRPC = 1,
UnknownRPC = 2,
UnableToConnect = 3,
NotAuthorized = 4,
BadHostname = 5,
Unknown = 255,
}Expand description
Improv Wi-Fi error codes, as transmitted on the Error State characteristic.
Variants
InvalidRPC = 1
RPC packet was malformed or had a bad checksum.
UnknownRPC = 2
The command sent is unknown.
UnableToConnect = 3
Credentials were received but the device couldn’t connect to the network.
NotAuthorized = 4
Credentials were sent via RPC but the Improv service is not authorised.
BadHostname = 5
A hostname value is not RFC 1123 compliant.
Unknown = 255
Catch-all for backend errors.
Implementations